@@ -1,7 +1,5 @@
 #!/bin/sh
 
-export QT_QPA_PLATFORM=wayland
-
 if [ ! -f /var/log/nvidia ] && [ ! -f /var/log/nvidia-470xx ] \
     && [ ! -f /var/log/nvidia-580xx ] && [ ! -f /var/log/nvidia-prime ]; then
     sudo sed -i -e 's|- packagechooserq@licenseq|#- packagechooserq@licenseq|' /usr/share/calamares/settings.conf
@@ -16,4 +14,4 @@ if [ ! -d /sys/firmware/efi/efivars ]; then
     sudo sed -i -e 's|defaultFileSystemType:  "xfs"|defaultFileSystemType:  "ext4"|' /usr/share/calamares/modules/partition.conf
 fi
 
-sudo /usr/bin/calamares -d > installation.log
+pkexec --disable-internal-agent env DBUS_SESSION_BUS_ADDRESS="$DBUS_SESSION_BUS_ADDRESS" DISPLAY="$DISPLAY" HOME="$HOME" QT_STYLE_OVERRIDE="$QT_STYLE_OVERRIDE" QT_QPA_PLATFORMTHEME="$QT_QPA_PLATFORMTHEME" QT_XCB_FORCE_SOFTWARE_OPENGL="$QT_XCB_FORCE_SOFTWARE_OPENGL" XAUTHORITY="$XAUTHORITY" XDG_CURRENT_DESKTOP="$XDG_CURRENT_DESKTOP" "/usr/bin/calamares" "-D6" "$@" > installation.log
