@@ -72,11 +72,11 @@ def is_zfs_root(partition):
 
 
 def create_conf(uuid, conf_path):
-    timeout = libcalamares.job.configuration["timeout"]
-    distribution = libcalamares.job.configuration["distribution"]
-    protocol = libcalamares.job.configuration["protocol"]
-    module_path = libcalamares.job.configuration["module_path"]
-    fallback = libcalamares.job.configuration["fallback"]
+    #timeout = libcalamares.job.configuration["timeout"]
+    #distribution = libcalamares.job.configuration["distribution"]
+    #protocol = libcalamares.job.configuration["protocol"]
+    #module_path = libcalamares.job.configuration["module_path"]
+    #fallback = libcalamares.job.configuration["fallback"]
     partitions = libcalamares.globalstorage.value("partitions")
 
     kernel_cmdline = ["quiet systemd.show_status=0"]
@@ -133,24 +133,26 @@ def create_conf(uuid, conf_path):
         kernel_cmdline.append(btrfs_params)
 
     lines = [
-        'timeout {!s}\n'.format(timeout),
+        'timeout 10\n',
         'default_entry: 1\n',
         'interface_branding_colour: 1\n',
         'remember_last_entry: yes\n',
         'term_background: CC000000\n',
         'term_foreground: FFFFFF\n',
         'term_margin: 100\n',
-        'wallpaper: boot():/limine/wallpaper.jpg',
+        'wallpaper: boot():/limine/wallpaper.jpg\n\n',
         '/KaOS Linux\n',
-        '    comment: {!s} GNU/Linux, with Linux kernel\n'.format(distribution),
-        '    protocol: {!s}\n'.format(protocol),
-        '    module_path: {!s}\n'.format(module_path),
+        '    comment: KaOS GNU/Linux, with Linux kernel\n',
+        '    protocol: linux\n',
+        '    kernel_path: boot():/vmlinuz-linux\n',
+        '    module_path: boot():/initramfs-linux.img\n',
         '    kernel_cmdline: {!s} rw\n\n'.format(" ".join(kernel_cmdline)),
         '',
         '/KaOS Linux Fallback\n',
-        '    comment: {!s} GNU/Linux, with Linux kernel, fallback\n'.format(distribution),
-        '    protocol: {!s}\n'.format(protocol),
-        '    module_path: {!s}\n'.format(fallback),
+        '    comment: KaOS GNU/Linux, with Linux kernel, fallback\n',
+        '    protocol: linux\n'
+        '    kernel_path: boot():/vmlinuz-linux\n',
+        '    module_path: boot():/initramfs-linux-fallback.img\n',
         '    kernel_cmdline: {!s} rw\n'.format(" ".join(kernel_cmdline)),
     ]
 
@@ -196,8 +198,8 @@ def install_limine():
     cmd = [
         "efibootmgr",
         "--create",
-        "--disk", f"{boot_p}",
-        "--part", f"{device[-1]}",
+        "--disk", f"{device}",
+        "--part", f"{boot_p}",
         "--label", "KaOS with Limine Bootloader",
         "--loader", "/limine/BOOTX64.EFI"
     ]
